@@ -13,7 +13,8 @@
 
 class KLineEdit;
 
-namespace Akonadi {
+namespace Akonadi
+{
 /**
  * @short A widget to input one or more email addresses.
  *
@@ -36,7 +37,7 @@ public:
     /**
      * Destroys the email address requester.
      */
-    ~EmailAddressRequester();
+    ~EmailAddressRequester() override;
 
     /**
      * Clears the text of the email address requester.
