@@ -12,14 +12,15 @@
 
 #include <QSortFilterProxyModel>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class LeafExtensionProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
 
 public:
     explicit LeafExtensionProxyModel(QObject *parent = nullptr);
-    ~LeafExtensionProxyModel();
+    ~LeafExtensionProxyModel() override;
 
     QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
     QModelIndex parent(const QModelIndex &index) const override;
