@@ -8,15 +8,13 @@
 */
 
 #include "addresseslocationwidget.h"
-#include "addresslocationwidget.h"
 #include "addressdelegate.h"
+#include "addresslocationwidget.h"
 #include "addressmodel.h"
 #include "contacteditor_debug.h"
 
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <QHBoxLayout>
-#include <QLabel>
 #include <QMenu>
 #include <QTreeView>
 
@@ -24,13 +22,13 @@ using namespace ContactEditor;
 
 AddressesLocationWidget::AddressesLocationWidget(QWidget *parent)
     : QSplitter(parent)
+    , mAddressLocationWidget(new AddressLocationWidget(this))
+    , mAddressesLocationView(new QTreeView(this))
     , mAddressModel(new AddressModel(this))
 {
-    mAddressLocationWidget = new AddressLocationWidget(this);
     mAddressLocationWidget->setObjectName(QStringLiteral("addresslocationwidget"));
     addWidget(mAddressLocationWidget);
 
-    mAddressesLocationView = new QTreeView(this);
     mAddressesLocationView->setRootIsDecorated(false);
     mAddressesLocationView->setHeaderHidden(true);
     mAddressesLocationView->setModel(mAddressModel);
@@ -51,7 +49,11 @@ AddressesLocationWidget::AddressesLocationWidget(QWidget *parent)
         mAddressLocationWidget->slotModifyAddress(idx.data(Qt::UserRole).value<KContacts::Address>(), idx.row());
     });
     connect(mAddressLocationWidget, &AddressLocationWidget::addNewAddress, mAddressModel, &AddressModel::addAddress);
-    connect(mAddressLocationWidget, &AddressLocationWidget::updateAddressCanceled, mAddressesLocationView->selectionModel(), &QItemSelectionModel::clearSelection);
+    connect(mAddressLocationWidget, &AddressLocationWidget::removeAddress, mAddressModel, &AddressModel::removeAddress);
+    connect(mAddressLocationWidget,
+            &AddressLocationWidget::updateAddressCanceled,
+            mAddressesLocationView->selectionModel(),
+            &QItemSelectionModel::clearSelection);
     connect(mAddressLocationWidget, &AddressLocationWidget::updateAddress, mAddressModel, &AddressModel::replaceAddress);
     connect(mAddressesLocationView, &QWidget::customContextMenuRequested, this, [this](QPoint pos) {
         const auto idx = mAddressesLocationView->indexAt(pos);
@@ -71,7 +73,7 @@ AddressesLocationWidget::AddressesLocationWidget(QWidget *parent)
     });
 
     setChildrenCollapsible(false);
-    setSizes(QList<int>() << 400 << 300);
+    setSizes({400, 300});
 }
 
 AddressesLocationWidget::~AddressesLocationWidget() = default;
