@@ -9,13 +9,15 @@
 #ifndef BLOGFEEDWIDGET_H
 #define BLOGFEEDWIDGET_H
 
-#include <QWidget>
 #include "contacteditor_private_export.h"
+#include <QWidget>
 class KLineEdit;
-namespace KContacts {
+namespace KContacts
+{
 class Addressee;
 }
-namespace ContactEditor {
+namespace ContactEditor
+{
 class CONTACTEDITOR_TESTS_EXPORT BlogfeedWidget : public QWidget
 {
     Q_OBJECT
@@ -25,6 +27,7 @@ public:
     void loadContact(const KContacts::Addressee &contact);
     void storeContact(KContacts::Addressee &contact) const;
     void setReadOnly(bool readOnly);
+
 private:
     KLineEdit *mBlogFeed = nullptr;
 };
